aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/ts/0x.js.ts8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/ts/0x.js.ts b/src/ts/0x.js.ts
index c0aaa06fa..ead1f56df 100644
--- a/src/ts/0x.js.ts
+++ b/src/ts/0x.js.ts
@@ -18,12 +18,12 @@ const MAX_DIGITS_IN_UNSIGNED_256_INT = 78;
export class ZeroEx {
/**
* Verifies that the elliptic curve signature `signature` was generated
* by signing `data` with the private key corresponding to the `signerETHAddressHex` address.
*/
- public static isValidSignature(dataHex: string, signature: ECSignature, signerETHAddressHex: string): boolean {
+ public static isValidSignature(dataHex: string, signature: ECSignature, signerAddressHex: string): boolean {
assert.isHexString('dataHex', dataHex);
assert.doesConformToSchema('signature', signature, ECSignatureSchema);
- assert.isETHAddressHex('signerAddress', signerETHAddressHex);
+ assert.isETHAddressHex('signerAddressHex', signerAddressHex);
const dataBuff = ethUtil.toBuffer(dataHex);
const msgHashBuff = ethUtil.hashPersonalMessage(dataBuff);
@@ -33,7 +33,7 @@ export class ZeroEx {
ethUtil.toBuffer(signature.r),
ethUtil.toBuffer(signature.s));
const retrievedAddress = ethUtil.bufferToHex(ethUtil.pubToAddress(pubKey));
- return retrievedAddress === signerETHAddressHex;
+ return retrievedAddress === signerAddressHex;
} catch (err) {
return false;
}
@@ -18,12 +18,12 @@ const MAX_DIGITS_IN_UNSIGNED_256_INT = 78;
/**
* Verifies that the elliptic curve signature `signature` was generated
- * by signing `data` with the private key corresponding to the `signerETHAddressHex` address.
+ * by signing `data` with the private key corresponding to the `signerAddressHex` address.
*/